/* Last modified: August 19, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none
Do-files called: none
Files needed: none

*/

*--------------------*
* Set these:

global datadir "/home/jeremy/data/jhr/data_code" // Location of data and code
global savedir "/home/jeremy/data/jhr/tex" // Location of figures and tables folders

*--------------------*

clear all
set more off
cd "$datadir"

* These are all fake data in fictional examples used as illustration.

clear all
set obs 18
gen id = _n <= _N/2
sort id
gen time = 1 if id != id[_n-1]
replace time = time[_n-1] + 1 if time == .
gen treat = 0
replace treat = 1 if time >= 4 & id == 1
bysort id: gen cumtreat = sum(treat) 
gen outcome = id * 3 + time
replace outcome = outcome - 0.5 * cumtreat if cumtreat <= 4
replace outcome = outcome - 2 if cumtreat > 4

reg outcome time if id == 0
predict trend0 if id == 0
reg outcome time if id == 1
predict trend1 if id == 1
gen outcome_detrend = outcome - trend0 if id == 0
replace outcome_detrend = outcome - trend1 if id == 1

/* OPTIONAL

xtset id time
forv i = 1/4 {
gen zzzo = S`i'.outcome
gen zzzt = S`i'.treat
qui reg zzzo zzzt i.time
eststo col`i'
qui reg zzzo zzzt i.time i.id#c.time
eststo col`i'b
drop zzz*
}

estout col1 col2 col3 col4 , keep(zzz*)
estout col1b col2b col3b col4b , keep(zzz*)

*/


* graphs

#delimit ;

replace time = time - 3 ;

line outcome time if id == 0 , lcolor(gs12) || 
 line outcome time if id == 1 , lcolor(black) || 
 line trend1 time , lcolor(black) lpattern(dot) 
legend(rows(1) order(1 "Control" 2 "Treated" 3 "Treated Trend")) 
ylabel(0(2)10) xline(0.0,lcolor(gs2)) xlabel(-2(1)6)
graphregion(color(white)) xtitle("Time") 
ytitle("Employment level", axis(1) margin(r+2.0) ) 
;
graph export "$savedir/figures/Fig3-toy_example_with_fit.png" , replace width(2000) ;

keep id time outcome* ; 

reshape wide outcome* , i(time) j(id) ;

gen diffoutcome = outcome1 - outcome0 ;
gen diffoutcome_detrend = outcome_detrend1 - outcome_detrend0 ;

gen prepost = (time > 0) ;
egen mdiffoutcome = mean(diffoutcome) , by(prepost) ;
egen mdiffoutcome_detrend = mean(diffoutcome_detrend) , by(prepost) ;

graph twoway bar diffoutcome time , barwidth(0.25) bcolor(gs12) xtitle("Time" , size(large))
ylabel(-1(1)4) xline(0.5,lcolor(gs2)) xlabel(-2(1)6) ||
line mdiffoutcome time if prepost == 0 , lcolor(black) lpattern(dash) yline(0,lcolor(black)) ||
line mdiffoutcome time  if prepost == 1 , lcolor(black) lpattern(dash)
ytitle("Difference in employment levels", axis(1) margin(r+2.0) size(large)) legend(off)
graphregion(color(white))
;
graph export "$savedir/figures/Fig4a-toy_example_diff_tc.png" , replace width(2000) ;

graph twoway bar diffoutcome_detrend time , barwidth(0.25) bcolor(gs12) xtitle("Time" , size(large))
ylabel(-1(1)4) xline(0.5,lcolor(gs2)) xlabel(-2(1)6) ||
line mdiffoutcome_detrend time if prepost == 0 , lcolor(black) lpattern(dash) yline(0,lcolor(black)) ||
line mdiffoutcome_detrend time  if prepost == 1 , lcolor(black) lpattern(dash)
ytitle("Difference in employment levels", axis(1) margin(r+2.0) size(large)) legend(off)
graphregion(color(white))
;
graph export "$savedir/figures/Fig4b-toy_example_diff_detrended.png" , replace width(2000) ;


#delimit cr

window manage close graph
clear all

****

* ILLUSTRATION OF STAGGERED TREATMENT

****

foreach case in 1 2 3 {

clear all
set obs 11
gen period = _n - 1 in 1/3
replace period = 2.999 in 4
replace period = _n - 2 in 5/7
replace period = 5.0001 in 8
replace period = _n - 3 in 9/11
label define period 3 "A treated (t{sub:1})" 5 "B treated (t{sub:2})" 8 "T"
label values period period

gen delta_treatment = (period >= 3 & period <= 5)


*local case = 3
* 1: no treatment effect
* 2: treatment effect on levels
* 3: treatment effect on growth rate


if `case' == 1 {  
gen empa = 1.5 + 0.2 * ceil(period)
replace empa = 1.5 + 0.2 * floor(period) if period > 3
gen empb = 0.7 + 0.2 * ceil(period)
replace empb = 0.7 + 0.2 * floor(period) if period > 3 
}

if `case' == 2 {
gen empa = 1.5 + 0.2 * ceil(period)
replace empa = 1.5 + 0.2 * floor(period) if period > 3
gen empb = 0.7 + 0.2 * ceil(period)
replace empb = 0.7 + 0.2 * floor(period) if period > 3 

replace empa = empa - 0.5 if period >= 3
replace empb = empb - 0.5 if period > 5 
}

if `case' == 3 {
gen empa = 1.5 + 0.2 * ceil(period)
replace empa = 1.5 + 0.2 * floor(period) if period > 3
gen empb = 0.7 + 0.2 * ceil(period)
replace empb = 0.7 + 0.2 * floor(period) if period > 3
 
replace empa = 2.1 + 0.05 * floor(period - 3) if period > 3
replace empb = 1.7 + 0.05 * floor(period - 5) if period > 5
}

gen diffemp = empa - empb
gen temp = diffemp if delta_treatment == 1
egen avgdiff_tr = mean(temp)
drop temp
gen temp = diffemp if delta_treatment == 0
egen avgdiff_not = mean(temp)
drop temp
gen diff_in_diff = round(avgdiff_tr - avgdiff_not , 0.00001)


#delimit ;
   line empa period if period >=0 & period < 3 , lcolor(gs8) lpattern(dash)
|| line empb period if period >=0 & period < 3  , lcolor(black) lpattern(solid)

|| line empa period if period >=  3 & period <= 5 , lcolor(gs8) lpattern(dash)
|| line empb period if period >=  3 & period <= 5  , lcolor(black) lpattern(solid)

|| line empa period if period >  5 & period <= 8 , lcolor(gs8) lpattern(dash)
|| line empb period if period >  5 & period <= 8  , lcolor(black) lpattern(solid)

xline(3 , lcolor(gs5) lpattern(dot)) 
xline(5 , lcolor(gs5) lpattern(dot))
ytitle("Employment level")
xtitle("Time") xlab(0 3 5 8 , valuelabels)
legend(rows(1) order(1 "Jurisdiction A" 2 "Jurisdiction B")) 
graphregion(color(white)) ylab(0) yscale(range(0 3.5))
;
#delimit cr


*if `case' == 1 {
*graph export "$savedir/figures/Fig-staggered-example-no-effect.png" , width(2000) replace
*}

if `case' == 2 {
graph export "$savedir/figures/Fig1a-staggered-example-level-effect.png" , width(2000) replace
}

if `case' == 3 {
graph export "$savedir/figures/Fig1b-staggered-example-growth-effect.png" , width(2000) replace
}

}

window manage close graph
clear all
