/* Last modified: August 19, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html
	      
Files needed: 

bds.dta - a cleaned version of the Business Dyanamics Statistics, linked to State minimum wage data and other covariates

*/

*--------------------*
* Set these:

global datadir "/home/jeremy/data/jhr/data_code" // Location of data and code
global savedir "/home/jeremy/data/jhr/tex" // Location of figures and tables folders

*--------------------*

clear all
set more off
cd "$datadir"

*--------------------*
* SUMMARY STATISTICS *
*--------------------*

use bds , clear

gen jg = D.emp / 1000
gen jgl = D.lemp
replace popall = popall / 1000
replace emp = emp / 1000

quietly estpost summarize mw realmw emp jg jgl popall share1559 rgspcap , detail
eststo sumstats_bds

#delimit ;
esttab sumstats_bds using "$savedir/tables/table_sumstats_BDS.tex" , replace fragment nogaps nomtitles nonum
cells(`"mean(fmt(a2)) sd(fmt(a3)) p50(fmt(a2))"') 
label collabels("Mean" "Std. Dev." "Median") 
coeflabels(mw "State minimum wage (\\$)" realmw "[-0.15cm]State minimum wage (\\$ real)" 
jg "[-0.15cm]Job growth (thousands)" jgl "[-0.15cm]Job growth (log)" emp "[-0.15cm]Jobs (thousands)" 
popall "[-0.15cm]Population (thousands)" share1559 "[-0.15cm]Share aged 15-59" rgspcap "[-0.15cm]GSP/capita (\\$ real)") 
;
#delimit cr

*--------------------*
*  CLASSIC RESULTS   *
*--------------------*

use bds , clear

quietly xtreg lemp lnmin i.year , fe robust cluster(state)
eststo col1
estadd local timefe "National"
estadd local timecontrols "No"
estadd local timetrend "No"

quietly xtreg lemp lnmin i.year lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col2
estadd local timefe "National"
estadd local timecontrols "Yes"
estadd local timetrend "No"

quietly xtreg lemp lnmin i.year#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col3
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "No"

quietly xtreg lemp F(0/1).lnmin i.year#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col4
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "No"

quietly xtreg lemp F(0/2).lnmin i.year#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
eststo col5
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "No"

quietly xtreg lemp lnmin i.year#i.censusreg lpopall share1559 lrgspcap i.state#c.year , fe robust cluster(state)
eststo col6
estadd local timefe "Regional"
estadd local timecontrols "Yes"
estadd local timetrend "Yes"

#delimit ;
esttab col1 col2 col3 col4 col5 col6 using "$savedir/tables/table_classic_BDS.tex", replace fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin*) nonotes nogaps nomtitles
coeflabels(lnmin "Log-MW" F.lnmin "1st lead of log-MW" F2.lnmin "2nd lead of log-MW" )
scalars("timefe [-0.2cm]Time FE" "timecontrols [-0.2cm]Time-varying controls" "timetrend [-0.2cm]Jurisdiction time trends")
;
#delimit cr

*--------------------*
*  LONG DIFFERENCES  *
*--------------------*

use bds , clear

forvalue i = 1/8 {

gen zzzlnmin = S`i'.lnmin // For better table format purposes

* Without trends:
qui reg S`i'.lemp zzzlnmin S`i'.lpopall S`i'.share1559 S`i'.lrgspcap i.year#i.censusreg , robust cluster(state)
estimates store col`i'

* With trends:
qui reg S`i'.lemp zzzlnmin i.state#c.year S`i'.lpopall S`i'.share1559 S`i'.lrgspcap i.year#i.censusreg , robust cluster(state)
estimates store col`i'b

drop zzzlnmin
}

#delimit ;
esttab col1 col2 col3 col4 col5 col6 col7 col8 using "$savedir/tables/table_longdiff_BDS.tex", replace fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin*) nonotes nogaps nomtitles noobs 
coeflabels(zzzlnmin "\textbf{Panel A: without trends} \\ Long difference in log-MW")
;
#delimit cr

#delimit ;
esttab col1b col2b col3b col4b col5b col6b col7b col8b using "$savedir/tables/table_longdiff_BDS.tex", append fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin*) nonotes nogaps nomtitles nonum
coeflabels(zzzlnmin "\textbf{Panel B: with trends} \\ Long difference in log-MW")
;
#delimit cr

*--------------------*
*  DISTRIBUTED LAG   *
*--------------------*

use bds, clear

* Add in 2012 nominal and log-real minimum wage values

keep statefips
duplicates drop
gen year = 2012
gen mw = .
gen lnmin = .
 replace mw = 7.25 if statefips == 1
 replace mw = 7.75 if statefips == 2
 replace mw = 7.65 if statefips == 4
 replace mw = 7.25 if statefips == 5
 replace mw = 8 if statefips == 6
 replace mw = 7.64 if statefips == 8
 replace mw = 8.25 if statefips == 9
 replace mw = 7.25 if statefips == 10
 replace mw = 8.25 if statefips == 11
 replace mw = 7.67 if statefips == 12
 replace mw = 7.25 if statefips == 13
 replace mw = 7.25 if statefips == 15
 replace mw = 7.25 if statefips == 16
 replace mw = 8.25 if statefips == 17
 replace mw = 7.25 if statefips == 18
 replace mw = 7.25 if statefips == 19
 replace mw = 7.25 if statefips == 20
 replace mw = 7.25 if statefips == 21
 replace mw = 7.25 if statefips == 22
 replace mw = 7.5 if statefips == 23
 replace mw = 7.25 if statefips == 24
 replace mw = 8 if statefips == 25
 replace mw = 7.4 if statefips == 26
 replace mw = 7.25 if statefips == 27
 replace mw = 7.25 if statefips == 28
 replace mw = 7.25 if statefips == 29
 replace mw = 7.65 if statefips == 30
 replace mw = 7.25 if statefips == 31
 replace mw = 8.25 if statefips == 32
 replace mw = 7.25 if statefips == 33
 replace mw = 7.25 if statefips == 34
 replace mw = 7.5 if statefips == 35
 replace mw = 7.25 if statefips == 36
 replace mw = 7.25 if statefips == 37
 replace mw = 7.25 if statefips == 38
 replace mw = 7.7 if statefips == 39
 replace mw = 7.25 if statefips == 40
 replace mw = 8.8 if statefips == 41
 replace mw = 7.25 if statefips == 42
 replace mw = 7.4 if statefips == 44
 replace mw = 7.25 if statefips == 45
 replace mw = 7.25 if statefips == 46
 replace mw = 7.25 if statefips == 47
 replace mw = 7.25 if statefips == 48
 replace mw = 7.25 if statefips == 49
 replace mw = 8.46 if statefips == 50
 replace mw = 7.25 if statefips == 51
 replace mw = 9.04 if statefips == 53
 replace mw = 7.25 if statefips == 54
 replace mw = 7.25 if statefips == 55
 replace mw = 7.25 if statefips == 56
 
 replace lnmin = 1.963741 if statefips == 1
 replace lnmin = 2.030432 if statefips == 2
 replace lnmin = 2.017445 if statefips == 4
 replace lnmin = 1.963741 if statefips == 5
 replace lnmin = 2.062181 if statefips == 6
 replace lnmin = 2.016137 if statefips == 8
 replace lnmin = 2.092953 if statefips == 9
 replace lnmin = 1.963741 if statefips == 10
 replace lnmin = 2.092953 if statefips == 11
 replace lnmin = 2.020056 if statefips == 12
 replace lnmin = 1.963741 if statefips == 13
 replace lnmin = 1.963741 if statefips == 15
 replace lnmin = 1.963741 if statefips == 16
 replace lnmin = 2.092953 if statefips == 17
 replace lnmin = 1.963741 if statefips == 18
 replace lnmin = 1.963741 if statefips == 19
 replace lnmin = 1.963741 if statefips == 20
 replace lnmin = 1.963741 if statefips == 21
 replace lnmin = 1.963741 if statefips == 22
 replace lnmin = 1.997643 if statefips == 23
 replace lnmin = 1.963741 if statefips == 24
 replace lnmin = 2.062181 if statefips == 25
 replace lnmin = 1.98422 if statefips == 26
 replace lnmin = 1.963741 if statefips == 27
 replace lnmin = 1.963741 if statefips == 28
 replace lnmin = 1.963741 if statefips == 29
 replace lnmin = 2.017445 if statefips == 30
 replace lnmin = 1.963741 if statefips == 31
 replace lnmin = 2.092953 if statefips == 32
 replace lnmin = 1.963741 if statefips == 33
 replace lnmin = 1.963741 if statefips == 34
 replace lnmin = 1.997643 if statefips == 35
 replace lnmin = 1.963741 if statefips == 36
 replace lnmin = 1.963741 if statefips == 37
 replace lnmin = 1.963741 if statefips == 38
 replace lnmin = 2.02396 if statefips == 39
 replace lnmin = 1.963741 if statefips == 40
 replace lnmin = 2.157491 if statefips == 41
 replace lnmin = 1.963741 if statefips == 42
 replace lnmin = 1.98422 if statefips == 44
 replace lnmin = 1.963741 if statefips == 45
 replace lnmin = 1.963741 if statefips == 46
 replace lnmin = 1.963741 if statefips == 47
 replace lnmin = 1.963741 if statefips == 48
 replace lnmin = 1.963741 if statefips == 49
 replace lnmin = 2.118089 if statefips == 50
 replace lnmin = 1.963741 if statefips == 51
 replace lnmin = 2.184399 if statefips == 53
 replace lnmin = 1.963741 if statefips == 54
 replace lnmin = 1.963741 if statefips == 55
 replace lnmin = 1.963741 if statefips == 56

append using bds

sort state year
xtset state year
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 year // Setting some technical factor-variable settings
set matsize 4000

estimates clear

gen delta_next = (f.mw > mw)
replace delta_next = . if year == 2012 // Not that this really matters for the estimations

**********

*  Results for distributed lags (first difference of employment) model

estimates clear

qui reg D.lemp DL(0/3).lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col1

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom1

qui reg D.lemp DL(0/3).lnmin DF.lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col2

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom2

qui reg D.lemp DL(0/3).lnmin DF(1/2).lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col3

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom3

qui reg D.lemp DL(0/3).lnmin i.year#i.censusdiv D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col4

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom4

qui reg D.lemp DL(0/3).lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap if indexedwage == 0 , robust cluster(state)
estimates store col5

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom5

qui reg D.lemp DL(0/3).lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap if year < 2008 , robust cluster(state)
estimates store col6

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom6

#delimit ;
esttab col1 col2 col3 col4 col5 col6 using "$savedir/tables/table_dlfd_BDS.tex", replace fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) keep(*lnmin*) nonotes nogaps noobs nomtitles
coeflabels(D.lnmin "Log-MW" FD.lnmin "1st lead of log-MW" F2D.lnmin "2nd lead of log-MW" 
LD.lnmin "1st lag of log-MW" L2D.lnmin "2nd lag of log-MW" L3D.lnmin "3rd lag of log-MW")
;
esttab lincom1 lincom2 lincom3 lincom4 lincom5 lincom6 using "$savedir/tables/table_dlfd_BDS.tex", append fragment
b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)
nonotes nogap nomtitles nonum coeflabels((1) "Sum MW effects") 
;
#delimit cr


clear all
